
dialogId("sp-v-no0", "font_big", "Lo and behold!")
dialogStr("Moet je zien!")


dialogId("sp-m-no1", "font_small", "Just imagine!")
dialogStr("Stel je voor!")


dialogId("sp-v-kdoby", "font_big", "Who could have guessed?!")
dialogStr("Wie had dat gedacht?!")


dialogId("sp-m-neopatrnost", "font_small", "Such carelessness.")
dialogStr("Wat slordig!")


dialogId("sp-v-zahynuli", "font_big", "Thousands perished - the whole city disappeared in the waves because of such ineptness.")
dialogStr("Duizenden zijn omgekomen, de hele stad is onder de golven verdwenen. Gewoon door zo'n stommiteit.")


dialogId("sp-m-vytazeny", "font_small", "Unplugged plug.")
dialogStr("Stop eruit getrokken.")


dialogId("sp-v-trapne", "font_big", "An embarrassing blunder.")
dialogStr("Een genante blunder.")


dialogId("sp-m-costim", "font_small", "What are we to do with it?")
dialogStr("Wat moeten we ermee?")


dialogId("sp-v-vratit0", "font_big", "We can try to put it back in place.")
dialogStr("We kunnen proberen om hem terug te doen.")


dialogId("sp-m-vratit0", "font_small", "And then? Shall we drink the water that poured in, or what?")
dialogStr("En dan? Moeten we al het water dat hier naarbinnen is gestroomd opdrinken, ofzo?")


dialogId("sp-v-vratit1", "font_big", "We can put it back in place as a token of our esteem of the citizens’ heroic effort to keep it afloat. As a memorial to their industrious, adroit and... persistent nature.")
dialogStr("We zouden hem terug kunnen stoppen als blijk van ons respect voor de heldhaftige pogingen van de burgers om de boel drijvende te houden. Als gedenkteken aan hun ijver, vindingrijkheid en... doorzettingsvermogen.")


dialogId("sp-m-vratit1", "font_small", "Of what? ‘Where are you running? I need to order eight swords.’ The Providence itself unplugged that hole. Just imagine you’d hear such things at home. Day by day.")
dialogStr("Aan wat? \"Waar ga jij zo snel naar toe? Ik moet acht zwaarden bestellen.\" De Voorzienigheid zelve heeft die stop eruit getrokken. Stel je voor dat je zulke dingen de hele dag overal moest aanhoren, dag in dag uit.")


dialogId("sp-m-kalet", "font_small", "And moreover: is it likely that anybody would ever come here? Only sepias will nibble it occasionally.")
dialogStr("En bovendien, denk je dat hier ooit iemand komt? Alleen zeekatjes zouden er af en toe aan knabbelen.")


dialogId("sp-v-pocit", "font_big", "We are going to feel good about it.")
dialogStr("We zouden er later trots op zijn.")


dialogId("sp-m-potize", "font_small", "We are going to feel down about it. Do you think the boss is going to believe it? A giant unplugged plug? And what have you done with it? We plugged it again. He, he, he.")
dialogStr("We zouden er later verdrietig over zijn. Denk je dat de baas dit gaat geloven? Een reusachtige stop? En wat heb je ermee gedaan? We hebben hem teruggestopt. He, he, he.")


dialogId("sp-v-vzit", "font_big", "You might be right. Maybe it would be better to take it along.")
dialogStr("Je hebt vast gelijk. Misschien dat we hem beter mee kunnen nemen.")


dialogId("sp-m-taky", "font_small", "I think so, too.")
dialogStr("Ja, dat denk ik ook.")


dialogId("sp-v-dotoho", "font_big", "Let ’s get to work.")
dialogStr("Aan de slag.")


dialogId("sp-m-nechat", "font_small", "What if we just leave that plug here?")
dialogStr("Waarom laten we die stop niet gewoon hier?")


dialogId("sp-v-centrala", "font_big", "What would the Agency say?")
dialogStr("Wat zou de Organisatie daarvan zeggen?")


dialogId("sp-v-jedno", "font_big", "I don’t think I mind what the boss is going to think about me.")
dialogStr("Ik denk niet dat het me veel kan schelen wat de baas van me denkt.")


dialogId("sp-m-vydrz", "font_small", "Hold on. We are sure to solve it.")
dialogStr("Wacht. Dit gaat vast wel lukken.")


dialogId("sp-m-spunt", "font_small", "The darned plug. What if we just make up something.")
dialogStr("Die rottige stop ook. Wat als we gewoon iets uit onze vinnen zuigen?")


dialogId("sp-v-co", "font_big", "Like what, for example?")
dialogStr("Zoals wat?")


dialogId("sp-m-vymluva0", "font_small", "Well, we could say that the city in fact never existed.")
dialogStr("Nou, we zouden kunnen zeggen dat de stad nooit heeft bestaan.")


dialogId("sp-m-vymluva1", "font_small", "Well, we could say that the city sank because the Arctic ice had melted.")
dialogStr("Nou, we zouden kunnen zeggen dat de stad is gezonken omdat de zuidpoolijskappen waren gesmolten.")


dialogId("sp-m-vymluva2", "font_small", "An earthquake could have sunk the city, for example.")
dialogStr("De stad zou kunnen zijn gezonken door een aardbeving, bij voorbeeld.")


dialogId("sp-m-vymluva3", "font_small", "A tsunami might have sunk the city, for example.")
dialogStr("Een tsunami zou de stad onder water hebben kunnen zetten, bij voorbeeld.")


dialogId("sp-m-vymluva4", "font_small", "We could try to say that a volcano erupted in the center of the city.")
dialogStr("We zouden kunnen beweren dat midden in de stad een vulkaan was uitgebarsten.")


dialogId("sp-v-nesmysl", "font_big", "That is just nonsense.")
dialogStr("Dat is gewoon onzin.")


dialogId("sp-v-ven", "font_big", "This time our goal is to get that plug out.")
dialogStr("Deze keer moeten we die stop het veld uit zien te krijgen.")

